@@ -8,9 +8,9 @@ import time
 from processor.helper.file.file_utils import exists_file
 from processor.logging.log_handler import getlogger
 from processor.helper.config.rundata_utils import put_in_currentdata,\
-    delete_from_currentdata, get_from_currentdata
+    delete_from_currentdata, get_from_currentdata, get_nodb
 from processor.helper.json.json_utils import get_field_value, json_from_file,\
-    collectiontypes, STRUCTURE
+    collectiontypes, STRUCTURE, make_snapshots_dir, store_snapshot
 from processor.helper.httpapi.restapi_azure import get_access_token,\
     get_web_client_data, get_client_secret, json_source
 from processor.connector.vault import get_vault_data
@@ -156,7 +156,7 @@ def get_node(token, sub_name, sub_id, node, user, snapshot_source):
     return db_record
 
 
-def populate_azure_snapshot(snapshot, snapshot_type='azure'):
+def populate_azure_snapshot(snapshot, container, snapshot_type='azure'):
     """ Populates the resources from azure."""
     dbname = config_value('MONGODB', 'dbname')
     snapshot_source = get_field_value(snapshot, 'source')
@@ -196,7 +196,12 @@ def populate_azure_snapshot(snapshot, snapshot_type='azure'):
                 data = get_node(token, sub_name, sub_id, node, snapshot_user, snapshot_source)
                 if data:
                     if validate:
-                        insert_one_document(data, data['collection'], dbname)
+                        if get_nodb():
+                            snapshot_dir = make_snapshots_dir(container)
+                            if snapshot_dir:
+                                store_snapshot(snapshot_dir, data)
+                        else:
+                            insert_one_document(data, data['collection'], dbname)
                         if 'masterSnapshotId' in node:
                             snapshot_data[node['snapshotId']] = node['masterSnapshotId']
                         else:
